pub enum VerificationRequestState {
Created {
our_methods: Vec<VerificationMethod>,
},
Requested {
their_methods: Vec<VerificationMethod>,
other_device_data: DeviceData,
},
Ready {
their_methods: Vec<VerificationMethod>,
our_methods: Vec<VerificationMethod>,
other_device_data: DeviceData,
},
Transitioned {
verification: Verification,
},
Done,
Cancelled(CancelInfo),
}Available on crate feature
e2e-encryption only.Expand description
An Enum describing the state the verification request is in.
Variants
Created
The verification request has been newly created by us.
Requested
The verification request was received from the other party.
Fields

other_device_data: DeviceDataThe device data of the device that responded to the verification request.
Ready
The verification request is ready to start a verification flow.
Fields

other_device_data: DeviceDataThe device data of the device that responded to the verification request.
Transitioned
The verification request has transitioned into a concrete verification flow. For example it transitioned into the emoji based SAS verification.
Fields

verification: VerificationThe concrete Verification object the verification request
transitioned into.
Done
The verification flow that was started with this request has finished.
Cancelled(CancelInfo)
The verification process has been cancelled.